##  Success Codes (2xx)
2xx status codes indicate that the request was successful and the desired action was completed. These codes provide positive feedback, allowing developers to proceed with further processing or updates. Success codes adhere to the guidelines specified in [Section 6.3 of RFC 7231![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdatatracker.ietf.org%2Fdoc%2Fhtml%2Frfc7231%23section-6.3 "https://datatracker.ietf.org/doc/html/rfc7231#section-6.3"), the Internet Standards Track document issued by the Internet Engineering Task Force (IETF).
Code | Meaning
---|---
200 (OK) | The request was successful, and the resource was retrieved or updated.


